from distutils.core import setup

setup(
	name		= '20191004',
	version		= '1.1.0',
	py_modules	= ['netster'],
	author		= 'hfpython',
	author_email= 'hfpython@headfirstlabs.com',
	url			= 'http://www.headfirstlabs.com',
	description = 'A simple printer of nested lists',
	)
	